@@ -237,4 +237,9 @@ public class ComponentsDefine {
 
     public static final OfficialComponent GRIZZLY = new OfficialComponent(147, "Grizzly");
 
+    public static final OfficialComponent WEBSPHERE = new OfficialComponent(148, "WebSphere");
+
+    public static final OfficialComponent AEROSPIKE = new OfficialComponent(149, "Aerospike");
+
+    public static final OfficialComponent NACOS = new OfficialComponent(150, "Nacos");
 }
