@@ -22,6 +22,7 @@ import java.util.LinkedList;
 import java.util.List;
 import org.apache.skywalking.apm.agent.core.context.trace.AbstractSpan;
 import org.apache.skywalking.apm.agent.core.context.trace.NoopSpan;
+import org.apache.skywalking.apm.agent.core.profile.ProfileStatusContext;
 
 /**
  * The <code>IgnoredTracerContext</code> represent a context should be ignored. So it just maintains the stack with an
@@ -35,6 +36,7 @@ public class IgnoredTracerContext implements AbstractTracerContext {
 
     private final CorrelationContext correlationContext;
     private final ExtensionContext extensionContext;
+    private final ProfileStatusContext profileStatusContext;
 
     private int stackDepth;
 
@@ -42,6 +44,7 @@ public class IgnoredTracerContext implements AbstractTracerContext {
         this.stackDepth = 0;
         this.correlationContext = new CorrelationContext();
         this.extensionContext = new ExtensionContext();
+        this.profileStatusContext = ProfileStatusContext.createWithNone();
     }
 
     @Override
@@ -56,7 +59,7 @@ public class IgnoredTracerContext implements AbstractTracerContext {
 
     @Override
     public ContextSnapshot capture() {
-        return new ContextSnapshot(null, -1, null, null, correlationContext, extensionContext);
+        return new ContextSnapshot(null, -1, null, null, correlationContext, extensionContext, profileStatusContext);
     }
 
     @Override
