@@ -35,6 +35,7 @@ public class URLParser {
     private static final String MSSQL_JDBC_URL_PREFIX = "jdbc:sqlserver:";
     private static final String KYLIN_JDBC_URK_PREFIX = "jdbc:kylin";
     private static final String IMPALA_JDBC_URK_PREFIX = "jdbc:impala";
+    private static final String CLICKHOUSE_JDBC_URK_PREFIX = "jdbc:clickhouse";
 
     public static ConnectionInfo parser(String url) {
         ConnectionURLParser parser = null;
@@ -57,6 +58,8 @@ public class URLParser {
             parser = new KylinJdbcURLParser(url);
         } else if (lowerCaseUrl.startsWith(IMPALA_JDBC_URK_PREFIX)) {
             parser = new ImpalaJdbcURLParser(url);
+        } else if (lowerCaseUrl.startsWith(CLICKHOUSE_JDBC_URK_PREFIX)) {
+            parser = new ClickHouseURLParser(url);
         }
         return parser.parse();
     }
