@@ -18,6 +18,9 @@
 
 package org.apache.skywalking.apm.plugin.jdbc.mysql;
 
+import static org.hamcrest.CoreMatchers.is;
+import static org.junit.Assert.assertThat;
+import static org.mockito.Mockito.when;
 import java.lang.reflect.Method;
 import org.apache.skywalking.apm.agent.core.context.trace.AbstractTracingSpan;
 import org.apache.skywalking.apm.agent.core.context.trace.SpanLayer;
@@ -33,21 +36,15 @@ import org.apache.skywalking.apm.network.trace.component.ComponentsDefine;
 import org.apache.skywalking.apm.plugin.jdbc.JDBCPluginConfig;
 import org.apache.skywalking.apm.plugin.jdbc.define.StatementEnhanceInfos;
 import org.apache.skywalking.apm.plugin.jdbc.trace.ConnectionInfo;
-import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.Mock;
-import org.powermock.modules.junit4.PowerMockRunner;
-import org.powermock.modules.junit4.PowerMockRunnerDelegate;
+import org.mockito.junit.MockitoJUnit;
+import org.mockito.junit.MockitoRule;
 
-import static org.hamcrest.CoreMatchers.is;
-import static org.junit.Assert.assertThat;
-import static org.powermock.api.mockito.PowerMockito.when;
-
-@RunWith(PowerMockRunner.class)
-@PowerMockRunnerDelegate(TracingSegmentRunner.class)
+@RunWith(TracingSegmentRunner.class)
 public class StatementExecuteMethodsInterceptorTest {
 
     private static final String SQL = "SELECT * FROM test";
@@ -57,6 +54,8 @@ public class StatementExecuteMethodsInterceptorTest {
 
     @Rule
     public AgentServiceRule serviceRule = new AgentServiceRule();
+    @Rule
+    public MockitoRule rule = MockitoJUnit.rule();
 
     private StatementExecuteMethodsInterceptor serviceMethodInterceptor;
 
@@ -70,6 +69,7 @@ public class StatementExecuteMethodsInterceptorTest {
 
     @Before
     public void setUp() {
+        JDBCPluginConfig.Plugin.JDBC.SQL_BODY_MAX_LENGTH = 2048;
         serviceMethodInterceptor = new StatementExecuteMethodsInterceptor();
 
         enhanceRequireCacheObject = new StatementEnhanceInfos(connectionInfo, "SELECT * FROM test", "CallableStatement");
@@ -81,11 +81,6 @@ public class StatementExecuteMethodsInterceptorTest {
         when(connectionInfo.getDatabasePeer()).thenReturn("localhost:3307");
     }
 
-    @After
-    public void clean() {
-        JDBCPluginConfig.Plugin.JDBC.SQL_BODY_MAX_LENGTH = 2048;
-    }
-
     @Test
     public void testCreateDatabaseSpan() throws Throwable {
         JDBCPluginConfig.Plugin.JDBC.SQL_BODY_MAX_LENGTH = 2048;
@@ -97,7 +92,7 @@ public class StatementExecuteMethodsInterceptorTest {
         assertThat(SegmentHelper.getSpans(segment).size(), is(1));
         AbstractTracingSpan span = SegmentHelper.getSpans(segment).get(0);
         SpanAssert.assertLayer(span, SpanLayer.DB);
-        assertThat(span.getOperationName(), is("H2/JDBC/CallableStatement/"));
+        assertThat(span.getOperationName(), is("H2/JDBC/CallableStatement/executeQuery"));
         SpanAssert.assertTag(span, 0, "H2");
         SpanAssert.assertTag(span, 1, "test");
         SpanAssert.assertTag(span, 2, SQL);
@@ -115,7 +110,7 @@ public class StatementExecuteMethodsInterceptorTest {
         assertThat(SegmentHelper.getSpans(segment).size(), is(1));
         AbstractTracingSpan span = SegmentHelper.getSpans(segment).get(0);
         SpanAssert.assertLayer(span, SpanLayer.DB);
-        assertThat(span.getOperationName(), is("H2/JDBC/CallableStatement/"));
+        assertThat(span.getOperationName(), is("H2/JDBC/CallableStatement/executeQuery"));
         SpanAssert.assertTag(span, 0, "H2");
         SpanAssert.assertTag(span, 1, "test");
         SpanAssert.assertTag(span, 2, "SELECT * F...");
